@@ -32,7 +32,12 @@ from typing import Any, Dict, Iterator, List, Set, Union
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .literals import BackupTypeFilter, ConditionalOperator, ReturnConsumedCapacity, Select
+from .literals import (
+    BackupTypeFilterType,
+    ConditionalOperatorType,
+    ReturnConsumedCapacityType,
+    SelectType,
+)
 from .type_defs import (
     ConditionTypeDef,
     ListBackupsOutputTypeDef,
@@ -54,7 +59,7 @@ __all__ = (
 
 class ListBackupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)[Show boto3-stubs documentation](./paginators.md#listbackupspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)[Show boto3-stubs documentation](./paginators.md#listbackupspaginator)
     """
 
     def paginate(
@@ -62,60 +67,60 @@ class ListBackupsPaginator(Boto3Paginator):
         TableName: str = None,
         TimeRangeLowerBound: datetime = None,
         TimeRangeUpperBound: datetime = None,
-        BackupType: BackupTypeFilter = None,
+        BackupType: BackupTypeFilterType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListBackupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
         [Show boto3-stubs documentation](./paginators.md#listbackupspaginator)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)[Show boto3-stubs documentation](./paginators.md#listtablespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)[Show boto3-stubs documentation](./paginators.md#listtablespaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTablesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
         [Show boto3-stubs documentation](./paginators.md#listtablespaginator)
         """
 
 
 class ListTagsOfResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)[Show boto3-stubs documentation](./paginators.md#listtagsofresourcepaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)[Show boto3-stubs documentation](./paginators.md#listtagsofresourcepaginator)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTagsOfResourceOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
         [Show boto3-stubs documentation](./paginators.md#listtagsofresourcepaginator)
         """
 
 
 class QueryPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.Query)[Show boto3-stubs documentation](./paginators.md#querypaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.Query)[Show boto3-stubs documentation](./paginators.md#querypaginator)
     """
 
     def paginate(
         self,
         TableName: str,
         IndexName: str = None,
-        Select: Select = None,
+        Select: SelectType = None,
         AttributesToGet: List[str] = None,
         ConsistentRead: bool = None,
         KeyConditions: Dict[str, ConditionTypeDef] = None,
         QueryFilter: Dict[str, ConditionTypeDef] = None,
-        ConditionalOperator: ConditionalOperator = None,
+        ConditionalOperator: ConditionalOperatorType = None,
         ScanIndexForward: bool = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ProjectionExpression: str = None,
         FilterExpression: str = None,
         KeyConditionExpression: str = None,
@@ -142,14 +147,14 @@ class QueryPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[QueryOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
         [Show boto3-stubs documentation](./paginators.md#querypaginator)
         """
 
 
 class ScanPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)[Show boto3-stubs documentation](./paginators.md#scanpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)[Show boto3-stubs documentation](./paginators.md#scanpaginator)
     """
 
     def paginate(
@@ -157,10 +162,10 @@ class ScanPaginator(Boto3Paginator):
         TableName: str,
         IndexName: str = None,
         AttributesToGet: List[str] = None,
-        Select: Select = None,
+        Select: SelectType = None,
         ScanFilter: Dict[str, ConditionTypeDef] = None,
-        ConditionalOperator: ConditionalOperator = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ConditionalOperator: ConditionalOperatorType = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         TotalSegments: int = None,
         Segment: int = None,
         ProjectionExpression: str = None,
@@ -189,6 +194,6 @@ class ScanPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ScanOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
         [Show boto3-stubs documentation](./paginators.md#scanpaginator)
         """
