@@ -26,12 +26,12 @@ from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.resources.collection import ResourceCollection
 
 from .literals import (
-    BillingMode,
-    ConditionalOperator,
-    ReturnConsumedCapacity,
-    ReturnItemCollectionMetrics,
-    ReturnValue,
-    Select,
+    BillingModeType,
+    ConditionalOperatorType,
+    ReturnConsumedCapacityType,
+    ReturnItemCollectionMetricsType,
+    ReturnValueType,
+    SelectType,
 )
 from .type_defs import (
     AttributeDefinitionTypeDef,
@@ -65,7 +65,7 @@ __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection"
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
     [Show boto3-stubs documentation](./service_resource.md#serviceresourcetablescollection)
     """
 
@@ -92,7 +92,7 @@ class ServiceResourceTablesCollection(ResourceCollection):
 
 class Table(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)[Show boto3-stubs documentation](./service_resource.md#table)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)[Show boto3-stubs documentation](./service_resource.md#table)
     """
 
     attribute_definitions: List[Any]
@@ -120,13 +120,13 @@ class Table(Boto3ServiceResource):
 
     def batch_writer(self, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
-        [Show boto3-stubs documentation](./service_resource.md#tablebatch-writermethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Show boto3-stubs documentation](./service_resource.md#tablebatch_writermethod)
         """
 
     def delete(self) -> DeleteTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.delete)
         [Show boto3-stubs documentation](./service_resource.md#tabledeletemethod)
         """
 
@@ -152,10 +152,10 @@ class Table(Boto3ServiceResource):
             ],
         ],
         Expected: Dict[str, ExpectedAttributeValueTypeDef] = None,
-        ConditionalOperator: ConditionalOperator = None,
-        ReturnValues: ReturnValue = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
+        ConditionalOperator: ConditionalOperatorType = None,
+        ReturnValues: ReturnValueType = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
         ConditionExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
         ExpressionAttributeValues: Dict[
@@ -179,14 +179,14 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> DeleteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
-        [Show boto3-stubs documentation](./service_resource.md#tabledelete-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Show boto3-stubs documentation](./service_resource.md#tabledelete_itemmethod)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
-        [Show boto3-stubs documentation](./service_resource.md#tableget-available-subresourcesmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Show boto3-stubs documentation](./service_resource.md#tableget_available_subresourcesmethod)
         """
 
     def get_item(
@@ -212,18 +212,18 @@ class Table(Boto3ServiceResource):
         ],
         AttributesToGet: List[str] = None,
         ConsistentRead: bool = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ProjectionExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
     ) -> GetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.get_item)
-        [Show boto3-stubs documentation](./service_resource.md#tableget-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Show boto3-stubs documentation](./service_resource.md#tableget_itemmethod)
         """
 
     def load(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.load)
         [Show boto3-stubs documentation](./service_resource.md#tableloadmethod)
         """
 
@@ -249,10 +249,10 @@ class Table(Boto3ServiceResource):
             ],
         ],
         Expected: Dict[str, ExpectedAttributeValueTypeDef] = None,
-        ReturnValues: ReturnValue = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
-        ConditionalOperator: ConditionalOperator = None,
+        ReturnValues: ReturnValueType = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
+        ConditionalOperator: ConditionalOperatorType = None,
         ConditionExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
         ExpressionAttributeValues: Dict[
@@ -276,20 +276,20 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> PutItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.put_item)
-        [Show boto3-stubs documentation](./service_resource.md#tableput-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Show boto3-stubs documentation](./service_resource.md#tableput_itemmethod)
         """
 
     def query(
         self,
         IndexName: str = None,
-        Select: Select = None,
+        Select: SelectType = None,
         AttributesToGet: List[str] = None,
         Limit: int = None,
         ConsistentRead: bool = None,
         KeyConditions: Dict[str, ConditionTypeDef] = None,
         QueryFilter: Dict[str, ConditionTypeDef] = None,
-        ConditionalOperator: ConditionalOperator = None,
+        ConditionalOperator: ConditionalOperatorType = None,
         ScanIndexForward: bool = None,
         ExclusiveStartKey: Dict[
             str,
@@ -310,7 +310,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ] = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ProjectionExpression: str = None,
         FilterExpression: Union[str, ConditionBase] = None,
         KeyConditionExpression: Union[str, ConditionBase] = None,
@@ -336,13 +336,13 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> QueryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.query)
         [Show boto3-stubs documentation](./service_resource.md#tablequerymethod)
         """
 
     def reload(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.reload)
         [Show boto3-stubs documentation](./service_resource.md#tablereloadmethod)
         """
 
@@ -351,9 +351,9 @@ class Table(Boto3ServiceResource):
         IndexName: str = None,
         AttributesToGet: List[str] = None,
         Limit: int = None,
-        Select: Select = None,
+        Select: SelectType = None,
         ScanFilter: Dict[str, ConditionTypeDef] = None,
-        ConditionalOperator: ConditionalOperator = None,
+        ConditionalOperator: ConditionalOperatorType = None,
         ExclusiveStartKey: Dict[
             str,
             Union[
@@ -373,7 +373,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ] = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         TotalSegments: int = None,
         Segment: int = None,
         ProjectionExpression: str = None,
@@ -401,14 +401,14 @@ class Table(Boto3ServiceResource):
         ConsistentRead: bool = None,
     ) -> ScanOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.scan)
         [Show boto3-stubs documentation](./service_resource.md#tablescanmethod)
         """
 
     def update(
         self,
         AttributeDefinitions: List["AttributeDefinitionTypeDef"] = None,
-        BillingMode: BillingMode = None,
+        BillingMode: BillingModeType = None,
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
         GlobalSecondaryIndexUpdates: List[GlobalSecondaryIndexUpdateTypeDef] = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
@@ -416,7 +416,7 @@ class Table(Boto3ServiceResource):
         ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None,
     ) -> "_Table":
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.update)
         [Show boto3-stubs documentation](./service_resource.md#tableupdatemethod)
         """
 
@@ -443,10 +443,10 @@ class Table(Boto3ServiceResource):
         ],
         AttributeUpdates: Dict[str, AttributeValueUpdateTypeDef] = None,
         Expected: Dict[str, ExpectedAttributeValueTypeDef] = None,
-        ConditionalOperator: ConditionalOperator = None,
-        ReturnValues: ReturnValue = None,
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
+        ConditionalOperator: ConditionalOperatorType = None,
+        ReturnValues: ReturnValueType = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
         UpdateExpression: str = None,
         ConditionExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
@@ -471,20 +471,20 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> UpdateItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.update_item)
-        [Show boto3-stubs documentation](./service_resource.md#tableupdate-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Show boto3-stubs documentation](./service_resource.md#tableupdate_itemmethod)
         """
 
     def wait_until_exists(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
-        [Show boto3-stubs documentation](./service_resource.md#tablewait-until-existsmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Show boto3-stubs documentation](./service_resource.md#tablewait_until_existsmethod)
         """
 
     def wait_until_not_exists(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
-        [Show boto3-stubs documentation](./service_resource.md#tablewait-until-not-existsmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Show boto3-stubs documentation](./service_resource.md#tablewait_until_not_existsmethod)
         """
 
 
@@ -493,36 +493,36 @@ _Table = Table
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.ServiceResource)[Show boto3-stubs documentation](./service_resource.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.ServiceResource)[Show boto3-stubs documentation](./service_resource.md)
     """
 
     tables: ServiceResourceTablesCollection
 
     def Table(self, name: str) -> _Table:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
         [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcetablemethod)
         """
 
     def batch_get_item(
         self,
         RequestItems: Dict[str, "KeysAndAttributesTypeDef"],
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
     ) -> BatchGetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
-        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcebatch-get-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcebatch_get_itemmethod)
         """
 
     def batch_write_item(
         self,
         RequestItems: Dict[str, List["WriteRequestTypeDef"]],
-        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
-        ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
     ) -> BatchWriteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
-        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcebatch-write-itemmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcebatch_write_itemmethod)
         """
 
     def create_table(
@@ -532,19 +532,19 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         KeySchema: List["KeySchemaElementTypeDef"],
         LocalSecondaryIndexes: List[LocalSecondaryIndexTypeDef] = None,
         GlobalSecondaryIndexes: List[GlobalSecondaryIndexTypeDef] = None,
-        BillingMode: BillingMode = None,
+        BillingMode: BillingModeType = None,
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
         SSESpecification: SSESpecificationTypeDef = None,
         Tags: List["TagTypeDef"] = None,
     ) -> _Table:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
-        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcecreate-tablemethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourcecreate_tablemethod)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
-        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourceget-available-subresourcesmethod)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [Show boto3-stubs documentation](./service_resource.md#dynamodbserviceresourceget_available_subresourcesmethod)
         """
